'''
## This file is autogenerated from macrosynergy setup.py.

It contains version information for the macrosynergy package.

short_version: 0.1.14

version: 0.1.14

full_version: 0.1.14

git_revision: b51ff39171c951941cd3e80e7d35b5e7bdd7bb88

release: True

'''
short_version: str = '0.1.14'
version: str = '0.1.14'
full_version: str = '0.1.14'
git_revision: str = 'b51ff39171c951941cd3e80e7d35b5e7bdd7bb88'
release: bool = True
if not release:
    version = full_version
